import { HazelReader, HazelWriter } from "@skeldjs/util";
import { ExtractEventTypes } from "@skeldjs/events";
import { SystemType } from "@skeldjs/constant";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { SystemStatusEvents } from "./events";
import { Hostable } from "../Hostable";
export declare const DeconState: {
    Enter: number;
    Closed: number;
    Exit: number;
    HeadingUp: number;
};
export interface DeconSystemData {
    timer: number;
    state: number;
}
export declare type DeconSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents<RoomType> & ExtractEventTypes<[]>;
/**
 * Represents a system responsible for the decontamination doors.
 *
 * See {@link DeconSystemEvents} for events to listen to.
 */
export declare class DeconSystem<RoomType extends Hostable = Hostable> extends SystemStatus<DeconSystemData, DeconSystemEvents, RoomType> implements DeconSystemData {
    static systemType: SystemType.Decontamination;
    systemType: SystemType.Decontamination;
    /**
     * How long before decontamination doors open.
     */
    timer: number;
    /**
     * The state of the decontamination system, to be calculated with {@link DeconState}
     */
    state: number;
    constructor(ship: InnerShipStatus<RoomType>, data?: HazelReader | DeconSystemData);
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
}
