import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { PlayerData } from "../PlayerData";
import { HqHudConsoleOpenEvent, HqHudConsoleCloseEvent, HqHudConsoleCompleteEvent, HqHudConsolesResetEvent } from "../events";
import { ExtractEventTypes } from "@skeldjs/events";
import { SystemStatusEvents } from "./events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { Hostable } from "../Hostable";
export interface UserConsolePair {
    playerid: number;
    consoleid: number;
}
export interface HqHudSystemData {
    active: UserConsolePair[];
    completed: Set<number>;
}
export declare type HqHudSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents<RoomType> & ExtractEventTypes<[
    HqHudConsolesResetEvent<RoomType>,
    HqHudConsoleOpenEvent<RoomType>,
    HqHudConsoleCloseEvent<RoomType>,
    HqHudConsoleCompleteEvent<RoomType>
]>;
export declare const HqHudSystemRepairTag: {
    readonly CompleteConsole: 16;
    readonly CloseConsole: 32;
    readonly OpenConsole: 64;
};
/**
 * Represents a system responsible for handling communication consoles on Mira HQ.
 *
 * See {@link HqHudSystemEvents} for events to listen to.
 */
export declare class HqHudSystem<RoomType extends Hostable = Hostable> extends SystemStatus<HqHudSystemData, HqHudSystemEvents, RoomType> implements HqHudSystemData {
    static systemType: SystemType.Communications;
    systemType: SystemType.Communications;
    /**
     * The timer until the consoles are reset.
     */
    timer: number;
    /**
     * The currently opened consoles.
     */
    active: UserConsolePair[];
    /**
     * The completed consoles.
     */
    completed: Set<number>;
    get sabotaged(): boolean;
    constructor(ship: InnerShipStatus<RoomType>, data?: HazelReader | HqHudSystemData);
    private _getIdx;
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    HandleSabotage(player: PlayerData | undefined, rpc: RepairSystemMessage | undefined): Promise<void>;
    private _resetConsoles;
    private _openConsole;
    /**
     * Mark the console as being used by your player.
     * @param consoleId The ID of the console to mark as being used.
     */
    openConsole(consoleId: number): Promise<void>;
    private _closeConsole;
    /**
     * Mark the console as no longer being used by your player.
     * @param consoleId The ID of the console to mark as not being used.
     */
    closeConsole(consoleId: number): Promise<void>;
    private _completeConsole;
    /**
     * Mark a console as completed.
     * @param consoleId The ID of the console to mark as completed.
     */
    completeConsole(consoleId: number): Promise<void>;
    private _repair;
    repair(): Promise<void>;
    HandleRepair(player: PlayerData, amount: number, rpc: RepairSystemMessage | undefined | undefined): Promise<void>;
    Detoriorate(delta: number): void;
}
